@@ -5,4 +5,8 @@
 #  geoapps is distributed under the terms and conditions of the MIT License
 #  (see LICENSE file at the root of this source code package).
 
-__version__ = "0.6.3"
+__version__ = "0.7.0"
+
+from .base.application import BaseApplication
+from .base.plot import PlotSelection2D
+from .base.selection import ObjectDataSelection
