@@ -9,15 +9,14 @@ import os
 from copy import deepcopy
 
 import numpy as np
-import requests
 import SimPEG
 from geoh5py.objects import Points
 from geoh5py.workspace import Workspace
 
-from geoapps.drivers.base_inversion import InversionDriver
-from geoapps.drivers.components import InversionData
-from geoapps.io.MagneticVector import MagneticVectorParams
-from geoapps.io.MagneticVector.constants import default_ui_json
+from geoapps.inversion.components import InversionData
+from geoapps.inversion.constants import default_ui_json
+from geoapps.inversion.driver import InversionDriver
+from geoapps.inversion.potential_fields import MagneticVectorParams
 from geoapps.utils.testing import Geoh5Tester
 
 geoh5 = Workspace("./FlinFlon.geoh5")
@@ -25,7 +24,9 @@ geoh5 = Workspace("./FlinFlon.geoh5")
 
 def setup_params(tmp):
     d_u_j = deepcopy(default_ui_json)
-    geotest = Geoh5Tester(geoh5, tmp, "test.geoh5", d_u_j, MagneticVectorParams)
+    geotest = Geoh5Tester(
+        geoh5, tmp, "test.geoh5", ui=d_u_j, params_class=MagneticVectorParams
+    )
     geotest.set_param("mesh", "{e334f687-df71-4538-ad28-264e420210b8}")
     geotest.set_param("data_object", "{538a7eb1-2218-4bec-98cc-0a759aa0ef4f}")
     geotest.set_param("topography_object", "{ab3c2083-6ea8-4d31-9230-7aad3ec09525}")
@@ -76,7 +77,7 @@ def test_survey_data(tmp_path):
         tile_spatial=2,
         z_from_topo=True,
         receivers_offset_z=50.0,
-        resolution=0,
+        resolution=0.0,
     )
 
     driver = InversionDriver(params, warmstart=False)
@@ -102,15 +103,15 @@ def test_survey_data(tmp_path):
     expected_dobs = np.column_stack(
         [bxx_data.values, byy_data.values, bzz_data.values]
     )[sorting].ravel()
-    survey_dobs = np.hstack([local_survey_a.dobs, local_survey_b.dobs])
-    np.testing.assert_array_equal(expected_dobs, survey_dobs)
+    survey_dobs = [local_survey_a.dobs, local_survey_b.dobs]
+    np.testing.assert_array_equal(expected_dobs, np.hstack(survey_dobs))
 
     # test savegeoh5iteration data
 
     driver.directiveList[-2].save_components(99, survey_dobs)
-    bxx_test = ws.get_entity("Iteration_99_mag_bxx")[0].values
-    byy_test = ws.get_entity("Iteration_99_mag_byy")[0].values
-    bzz_test = ws.get_entity("Iteration_99_mag_bzz")[0].values
+    bxx_test = ws.get_entity("Iteration_99_bxx")[0].values
+    byy_test = ws.get_entity("Iteration_99_byy")[0].values
+    bzz_test = ws.get_entity("Iteration_99_bzz")[0].values
 
     np.testing.assert_array_equal(bxx_test, bxx_data.values)
     np.testing.assert_array_equal(byy_test, byy_data.values)
@@ -119,19 +120,19 @@ def test_survey_data(tmp_path):
     driver.directiveList[-1].save_components(99, survey_dobs)
 
     assert np.all(
-        ws.get_entity("Iteration_99_mag_bxx_Residual")[0].values == 0
+        ws.get_entity("Iteration_99_bxx_Residual")[0].values == 0
     ), "Residual data should be zero."
     assert np.all(
-        ws.get_entity("Iteration_99_mag_byy_Residual")[0].values == 0
+        ws.get_entity("Iteration_99_byy_Residual")[0].values == 0
     ), "Residual data should be zero."
     assert np.all(
-        ws.get_entity("Iteration_99_mag_bzz_Residual")[0].values == 0
+        ws.get_entity("Iteration_99_bzz_Residual")[0].values == 0
     ), "Residual data should be zero."
 
 
 def test_save_data(tmp_path):
     ws, params = setup_params(tmp_path)
-    locs = ws.get_entity(params.data_object)[0].centroids
+    locs = params.data_object.centroids
     window = {"center": [np.mean(locs[:, 0]), np.mean(locs[:, 1])], "size": [100, 100]}
     data = InversionData(ws, params, window)
 
@@ -140,11 +141,11 @@ def test_save_data(tmp_path):
 
 def test_get_uncertainty_component(tmp_path):
     ws, params = setup_params(tmp_path)
-    locs = ws.get_entity(params.data_object)[0].centroids
+    locs = params.data_object.centroids
     window = {"center": [np.mean(locs[:, 0]), np.mean(locs[:, 1])], "size": [100, 100]}
-    params.tmi_uncertainty = 1
+    params.tmi_uncertainty = 1.0
     data = InversionData(ws, params, window)
-    unc = data.get_uncertainty_component("tmi")
+    unc = data.get_data()[2]["tmi"]
     assert len(np.unique(unc)) == 1
     assert np.unique(unc)[0] == 1
     assert len(unc) == len(data.mask)
@@ -152,7 +153,7 @@ def test_get_uncertainty_component(tmp_path):
 
 def test_parse_ignore_values(tmp_path):
     ws, params = setup_params(tmp_path)
-    locs = ws.get_entity(params.data_object)[0].centroids
+    locs = params.data_object.centroids
     window = {"center": [np.mean(locs[:, 0]), np.mean(locs[:, 1])], "size": [100, 100]}
     params.ignore_values = "<99"
     data = InversionData(ws, params, window)
@@ -175,7 +176,7 @@ def test_parse_ignore_values(tmp_path):
 
 def test_set_infinity_uncertainties(tmp_path):
     ws, params = setup_params(tmp_path)
-    locs = ws.get_entity(params.data_object)[0].centroids
+    locs = params.data_object.centroids
     window = {"center": [np.mean(locs[:, 0]), np.mean(locs[:, 1])], "size": [100, 100]}
     data = InversionData(ws, params, window)
     test_data = np.array([0, 1, 2, 3, 4, 5])
@@ -209,7 +210,7 @@ def test_set_infinity_uncertainties(tmp_path):
 
 def test_displace(tmp_path):
     ws, params = setup_params(tmp_path)
-    locs = ws.get_entity(params.data_object)[0].centroids
+    locs = params.data_object.centroids
     window = {"center": [np.mean(locs[:, 0]), np.mean(locs[:, 1])], "size": [100, 100]}
     data = InversionData(ws, params, window)
     test_locs = np.array([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0], [7.0, 8.0, 9.0]])
@@ -231,7 +232,7 @@ def test_displace(tmp_path):
 
 def test_drape(tmp_path):
     ws, params = setup_params(tmp_path)
-    locs = ws.get_entity(params.data_object)[0].centroids
+    locs = params.data_object.centroids
     window = {"center": [np.mean(locs[:, 0]), np.mean(locs[:, 1])], "size": [100, 100]}
     data = InversionData(ws, params, window)
     test_locs = np.array([[1.0, 2.0, 1.0], [2.0, 1.0, 1.0], [8.0, 9.0, 1.0]])
@@ -244,19 +245,20 @@ def test_drape(tmp_path):
 
 def test_normalize(tmp_path):
     ws, params = setup_params(tmp_path)
-    locs = ws.get_entity(params.data_object)[0].centroids
+    locs = params.data_object.centroids
     window = {"center": [np.mean(locs[:, 0]), np.mean(locs[:, 1])], "size": [100, 100]}
     data = InversionData(ws, params, window)
-    data.data = {"tmi": np.array([1.0, 2.0, 3.0]), "gz": np.array([1.0, 2.0, 3.0])}
-    data.components = list(data.data.keys())
-    test_data = data.normalize(data.data)
+    data.observed = {"tmi": np.array([1.0, 2.0, 3.0]), "gz": np.array([1.0, 2.0, 3.0])}
+    data.components = list(data.observed.keys())
+    data.normalizations = data.get_normalizations()
+    test_data = data.normalize(data.observed)
     assert list(data.normalizations.values()) == [1, -1]
-    assert all(test_data["gz"] == (-1 * data.data["gz"]))
+    assert all(test_data["gz"] == (-1 * data.observed["gz"]))
 
 
 def test_get_survey(tmp_path):
     ws, params = setup_params(tmp_path)
-    locs = ws.get_entity(params.data_object)[0].centroids
+    locs = params.data_object.centroids
     window = {"center": [np.mean(locs[:, 0]), np.mean(locs[:, 1])], "size": [100, 100]}
     data = InversionData(ws, params, window)
     survey, _ = data.survey()
