@@ -7,7 +7,7 @@
 
 from geoh5py.workspace import Workspace
 
-from geoapps.inversion.em1d_inversion_app import InversionApp
+from geoapps.inversion.airborne_electromagnetics.application import InversionApp
 
 project = "FlinFlon.geoh5"
 geoh5 = Workspace(project)
@@ -15,7 +15,12 @@ geoh5 = Workspace(project)
 
 def test_em1d_inversion(tmp_path):
     app = InversionApp(
-        h5file=project, plot_result=False, inversion_parameters={"max_iterations": 1}
+        h5file=project,
+        plot_result=False,
+        inversion_parameters={
+            "max_iterations": 1,
+        },
     )
+    app.inversion_parameters.reference_model.options.value = "Value"
     app.write.click()
     app.trigger.click()
