@@ -9,12 +9,11 @@
 from pathlib import Path
 
 import numpy as np
-import pytest
 from geoh5py.objects import Curve
 from geoh5py.workspace import Workspace
 from ipywidgets import Widget
 
-from geoapps.processing.peak_finder import PeakFinder
+from geoapps.peak_finder.application import PeakFinder
 
 # pytest.skip("eliminating conflicting test.", allow_module_level=True)
 
@@ -46,12 +45,11 @@ def test_peak_finder_app(tmp_path):
         "data": curve.find_or_create_property_group(name="obs").uid,
         "line_field": line.uid,
         "line_id": 1.0,
-        "width": 10,
-        "center": 1,
+        "width": 10.0,
+        "center": 1.0,
         "min_amplitude": 1e-2,
         "min_width": 1e-2,
-        "max_migration": 1,
-        "plot_result": False,
+        "max_migration": 1.0,
         "group_auto": True,
     }
     app.geoh5 = ws
@@ -62,7 +60,7 @@ def test_peak_finder_app(tmp_path):
         else:
             setattr(app, param, value)
 
-    app.trigger.click()
+    app.trigger_click(None)
 
     anomalies = app.lines.anomalies
     assert len(anomalies) == 3, f"Expected 3 groups. Found {len(anomalies)}"
